Learn R Programming

epicmodel (version 0.2.1)

steplist_party: Birthday party example steplist

Description

An example steplist, which contains the steps that tell Clara, under which conditions her birthday party will be a success.

Usage

steplist_party

Arguments

Format

An object of class epicmodel_steplist, which is a list of 8 data.frames. See new_steplist() for the detailed structure of epicmodel_steplist class objects.